@@ -13,8 +13,21 @@ end
 function ShowLastOrb()
 	tOrb = Level.GetTemplate("orb")
 	oOrb = Level.CreateObject("orb_cave", tOrb, -48.220, -21.117, -60.686, 0, 0, 0)
-	
-	GUI.TutorialText("Now, enter the cave of the Sasquatch\nto begin your adventure.", 12)
+
+	GUI.TutorialText("Now, enter the cave of the Sasquatch to begin your adventure.", 12)
+end
+
+-- Display lose message
+function OnHitZone(HitType, Zone, HitObject)
+
+	if HitObject == Player then
+		Level.Lose("You flew off into space!")
+		return 1
+	else
+		Object.SetLifetime(HitObject, 2)
+	end
+
+	return 0
 end
 
 -- Set up goal
