@@ -23,5 +23,5 @@ Level.CreateConstraint("constraint0", tConstraint, oLog, 0)
 Object.SetAngularVelocity(oLog, 0, 0, 2)
 
 -- Show text
-GUI.TutorialText("When rolling on the cylinder, tap [" .. KEY_RIGHT .. "]\nto counteract the rotation.", 10)
+GUI.TutorialText("When rolling on the cylinder, tap [" .. KEY_RIGHT .. "] to counteract the rotation.", 10)
 Timer.DelayedFunction("ShowMoreText", 15)
