@@ -15,5 +15,5 @@ end
 GoalCount = 1
 
 -- Show text
-GUI.TutorialText("Press [" .. KEY_FORWARD .. "], [" .. KEY_LEFT .. "], [" .. KEY_BACK .. "], [" .. KEY_RIGHT .. "] to move.\nThe mouse is used to look around.", 15)
+GUI.TutorialText("Press [" .. KEY_FORWARD .. "], [" .. KEY_LEFT .. "], [" .. KEY_BACK .. "], [" .. KEY_RIGHT .. "] to move. The mouse is used to look around.", 15)
 Timer.DelayedFunction("ShowMoreText", 20)
