@@ -1,6 +1,6 @@
 -- Display tutorial text
 function ShowMoreText()
-	GUI.TutorialText("Get some speed, then jump as you cross\nthe blue patch. Hit [" .. KEY_RESET .. "] to retry the level.", 25)
+	GUI.TutorialText("Get some speed, then jump as you cross the blue patch. Hit [" .. KEY_RESET .. "] to retry the level.", 25)
 end
 
 -- Called when an orb is deactivated
@@ -15,5 +15,5 @@ end
 GoalCount = 1
 
 -- Show text
-GUI.TutorialText("Jumping is very important for climbing\nhills.", 5)
+GUI.TutorialText("Jumping is very important for climbing hills.", 5)
 Timer.DelayedFunction("ShowMoreText", 6)
\ No newline at end of file
